==> istio-model-v1beta1-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl<A extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    this.withName(instance.getName()); 
    this.withPath(instance.getPath()); 
    this.withTtl(instance.getTtl()); 
  }
  private String name;
  private String path;
  private String ttl;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getTtl() {
    return this.ttl;
  }
  public A withTtl(String ttl) {
    this.ttl=ttl; return (A) this;
  }
  public Boolean hasTtl() {
    return this.ttl != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl that = (LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (ttl != null ? !ttl.equals(that.ttl) :that.ttl != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  path,  ttl,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (ttl != null) { sb.append("ttl:"); sb.append(ttl); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl<A extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBHttpCookieValueFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl(LoadBalancerSettingsConsistentHashLBHttpCookieValue instance) {
    if (instance != null) {
      this.withName(instance.getName());
      this.withPath(instance.getPath());
      this.withTtl(instance.getTtl());
    }
  }
  private String name;
  private String path;
  private String ttl;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getTtl() {
    return this.ttl;
  }
  public A withTtl(String ttl) {
    this.ttl=ttl; return (A) this;
  }
  public Boolean hasTtl() {
    return this.ttl != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl that = (LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(ttl, that.ttl)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  path,  ttl,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (ttl != null) { sb.append("ttl:"); sb.append(ttl); }
    sb.append("}");
    return sb.toString();
  }
  
}
